import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixContactsV4Attachment from './contacts-v4-attachment-attachments.http.js';
import { transformRESTImageToSDKImage } from '@wix/sdk-runtime/transformations/image';
import { transformRESTDocumentToSDKDocument } from '@wix/sdk-runtime/transformations/document';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var AttachmentType;
(function (AttachmentType) {
    /** Unknown attachment type. */
    AttachmentType["UNKNOWN"] = "UNKNOWN";
    /** Attachment is an image file. */
    AttachmentType["IMAGE"] = "IMAGE";
    /** Attachment is a document or any non-image file type. */
    AttachmentType["OTHER"] = "OTHER";
})(AttachmentType || (AttachmentType = {}));
export var CrmAttachmentAttachmentType;
(function (CrmAttachmentAttachmentType) {
    CrmAttachmentAttachmentType["UNKNOWN"] = "UNKNOWN";
    CrmAttachmentAttachmentType["DOCUMENT"] = "DOCUMENT";
    CrmAttachmentAttachmentType["IMAGE"] = "IMAGE";
})(CrmAttachmentAttachmentType || (CrmAttachmentAttachmentType = {}));
export var DemoContactType;
(function (DemoContactType) {
    DemoContactType["KAT"] = "KAT";
    DemoContactType["DAN"] = "DAN";
})(DemoContactType || (DemoContactType = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Generates an upload URL for uploading a file as an attachment to a specified contact.
 *
 * To learn how to use the generated upload URL in the response to upload an attachment file,
 * see the Upload API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/media/files/upload-api) | [REST](https://dev.wix.com/docs/rest/assets/media/media-manager/files/upload-api)).
 * @param contactId - ID of the contact for whom the attachment is being uploaded.
 * @param fileName - File name of the attachment including the extension, for example, `contact-cv.pdf`.
 * @public
 * @requiredField contactId
 * @requiredField fileName
 * @requiredField options
 * @requiredField options.mimeType
 * @permissionId CONTACTS_ATTACHMENTS.MODIFY
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GenerateAttachmentUploadUrl
 */
export async function generateAttachmentUploadUrl(contactId, fileName, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        contactId: contactId,
        fileName: fileName,
        mimeType: options?.mimeType,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.generateAttachmentUploadUrl(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0]',
                fileName: '$[1]',
                mimeType: '$[2].mimeType',
            },
            singleArgumentUnchanged: false,
        }, ['contactId', 'fileName', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of attachments associated with a specified contact.
 * @param contactId - Contact ID for the attachments to be listed.
 * @public
 * @requiredField contactId
 * @permissionId CONTACTS_ATTACHMENTS.VIEW
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.ListAttachments
 */
export async function listAttachments(contactId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        contactId: contactId,
        paging: options?.paging,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.listAttachments(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTImageToSDKImage,
                paths: [
                    { path: 'attachments.image' },
                    { path: 'attachments.previewImage' },
                ],
            },
            {
                transformFn: transformRESTDocumentToSDKDocument,
                paths: [{ path: 'attachments.document' }],
            },
        ]));
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { contactId: '$[0]', paging: '$[1].paging' },
            singleArgumentUnchanged: false,
        }, ['contactId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Deletes the specified attachment from the specified contact.
 * @public
 * @requiredField identifiers
 * @requiredField identifiers.attachmentId
 * @requiredField identifiers.contactId
 * @permissionId CONTACTS_ATTACHMENTS.MODIFY
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.DeleteAttachment
 */
export async function deleteAttachment(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        contactId: identifiers?.contactId,
        attachmentId: identifiers?.attachmentId,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.deleteAttachment(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0].contactId',
                attachmentId: '$[0].attachmentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves the specified attachment for the specified contact.
 * @public
 * @requiredField identifiers
 * @requiredField identifiers.attachmentId
 * @requiredField identifiers.contactId
 * @permissionId CONTACTS_ATTACHMENTS.VIEW
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @returns The requested attachment.
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GetAttachment
 */
export async function getAttachment(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        contactId: identifiers?.contactId,
        attachmentId: identifiers?.attachmentId,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.getAttachment(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTImageToSDKImage,
                paths: [
                    { path: 'attachment.image' },
                    { path: 'attachment.previewImage' },
                ],
            },
            {
                transformFn: transformRESTDocumentToSDKDocument,
                paths: [{ path: 'attachment.document' }],
            },
        ]))?.attachment;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0].contactId',
                attachmentId: '$[0].attachmentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=contacts-v4-attachment-attachments.universal.js.map